@@ -9,7 +9,6 @@
 // app
 #include "kpartloader_version.h"
 // KF
-#include <kcoreaddons_version.h>
 #include <KAboutData>
 #include <KActionCollection>
 #include <KLocalizedString>
@@ -68,13 +67,9 @@ void KPartLoaderWindow::aboutKPart()
 
 int main( int argc, char **argv )
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
-
     QApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("kpartloader");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kpartloader"));
 
     KAboutData aboutData(
         QStringLiteral("kpartloader"),
